@@ -3,8 +3,9 @@ from .project import (normalize_project, namespaces, page_assessments, page_asse
                       admins_and_user_groups, admin_statistics, patroller_statistics, steward_statistics)
 from .quote import random_quote, single_quote, all_quotes
 from .user import (simple_edit_count, number_of_pages_created, pages_created, pages_created_iter,
-                   automated_edit_counter,  # ...
-                   log_counts, namespace_totals, month_counts, time_card)
+                   automated_edit_counter,  non_automated_edits, automated_edits,  edit_summaries, top_edits,
+                   category_edit_counter, log_counts, namespace_totals, month_counts, time_card)
 
+from .exceptions import BaseXToolsException, NotFound, TooManyEdits
 
-__version__ = "0.0.3"
+__version__ = "0.1.0"
