@@ -4,6 +4,7 @@ Internal base utilities.
 
 from typing import Optional, Tuple, Any, Sequence
 
+import time
 import requests
 from .exceptions import BaseXToolsException, NotFound, TooManyEdits
 
@@ -41,7 +42,8 @@ def error_exception(response: dict) -> Optional[BaseXToolsException]:
         return BaseXToolsException(error["message"], code)
 
     if error.startswith("No matching result") \
-            or error.endswith("is not a valid project"):
+            or error.endswith("is not a valid project") \
+            or error == "The requested user does not exist":
         return NotFound(error)
 
     if error.startswith("User has made too many edits!"):
@@ -50,16 +52,23 @@ def error_exception(response: dict) -> Optional[BaseXToolsException]:
     return BaseXToolsException(str(error))
 
 
-def get(path: str, params=None):
+def get(path: str, params=None, retry=3, retry_delay=1):
     """
     Perform a GET request against the API.
     :param path:
     :param params:
+    :param retry:
+    :param retry_delay:
     :return:
     """
     r = requests.get(url(path), params=params)
-    # Note: this sometimes fail but I can't reproduce the exact behavior for now.
-    # TODO better handle the error.
+    # 'Proxy error'
+    if r.status_code == 502:
+        if retry > 0:
+            time.sleep(retry_delay)
+            return get(path, params, retry - 1)
+        r.raise_for_status()
+
     response = r.json()
     exception = error_exception(response)
     if exception:
@@ -87,9 +96,6 @@ def build_path(path_format: str, params: Sequence[Tuple[str, Any, str]]) -> str:
     params_dict = {}
 
     def has_more(index):
-        if index >= len(params):
-            return False
-
         for _, val, _ in params[index+1:]:
             if val:
                 return True
